// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef MIMETREEPARSER_VERSION_H
#define MIMETREEPARSER_VERSION_H

#define MIMETREEPARSER_VERSION_STRING "6.6.3"
#define MIMETREEPARSER_VERSION_MAJOR 6
#define MIMETREEPARSER_VERSION_MINOR 6
#define MIMETREEPARSER_VERSION_PATCH 3
#define MIMETREEPARSER_VERSION ((6<<16)|(6<<8)|(3))

#endif
