
#ifndef MIMETREEPARSER_EXPORT_H
#define MIMETREEPARSER_EXPORT_H

#ifdef MIMETREEPARSER_STATIC_DEFINE
#  define MIMETREEPARSER_EXPORT
#  define MIMETREEPARSER_NO_EXPORT
#else
#  ifndef MIMETREEPARSER_EXPORT
#    ifdef KPim6MimeTreeParser_EXPORTS
        /* We are building this library */
#      define MIMETREEPARSER_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define MIMETREEPARSER_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef MIMETREEPARSER_NO_EXPORT
#    define MIMETREEPARSER_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef MIMETREEPARSER_DECL_DEPRECATED
#  define MIMETREEPARSER_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef MIMETREEPARSER_DECL_DEPRECATED_EXPORT
#  define MIMETREEPARSER_DECL_DEPRECATED_EXPORT MIMETREEPARSER_EXPORT MIMETREEPARSER_DECL_DEPRECATED
#endif

#ifndef MIMETREEPARSER_DECL_DEPRECATED_NO_EXPORT
#  define MIMETREEPARSER_DECL_DEPRECATED_NO_EXPORT MIMETREEPARSER_NO_EXPORT MIMETREEPARSER_DECL_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef MIMETREEPARSER_NO_DEPRECATED
#    define MIMETREEPARSER_NO_DEPRECATED
#  endif
#endif
#include <mimetreeparser_version.h>

#define MIMETREEPARSER_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#if defined(MIMETREEPARSER_NO_DEPRECATED)
#  undef MIMETREEPARSER_DEPRECATED
#  define MIMETREEPARSER_DEPRECATED_EXPORT MIMETREEPARSER_EXPORT
#  define MIMETREEPARSER_DEPRECATED_NO_EXPORT MIMETREEPARSER_NO_EXPORT
#elif defined(MIMETREEPARSER_NO_DEPRECATED_WARNINGS)
#  define MIMETREEPARSER_DEPRECATED
#  define MIMETREEPARSER_DEPRECATED_EXPORT MIMETREEPARSER_EXPORT
#  define MIMETREEPARSER_DEPRECATED_NO_EXPORT MIMETREEPARSER_NO_EXPORT
#else
#  define MIMETREEPARSER_DEPRECATED MIMETREEPARSER_DECL_DEPRECATED
#  define MIMETREEPARSER_DEPRECATED_EXPORT MIMETREEPARSER_DECL_DEPRECATED_EXPORT
#  define MIMETREEPARSER_DEPRECATED_NO_EXPORT MIMETREEPARSER_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define MIMETREEPARSER_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define MIMETREEPARSER_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef MIMETREEPARSER_NO_DEPRECATED
#  define MIMETREEPARSER_DISABLE_DEPRECATED_BEFORE_AND_AT MIMETREEPARSER_VERSION
#endif
#ifdef MIMETREEPARSER_NO_DEPRECATED_WARNINGS
#  define MIMETREEPARSER_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef MIMETREEPARSER_DEPRECATED_WARNINGS_SINCE
#  ifdef MIMETREEPARSER_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define MIMETREEPARSER_DEPRECATED_WARNINGS_SINCE MIMETREEPARSER_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define MIMETREEPARSER_DEPRECATED_WARNINGS_SINCE MIMETREEPARSER_VERSION
#  endif
#endif

#ifndef MIMETREEPARSER_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define MIMETREEPARSER_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef MIMETREEPARSER_DEPRECATED
#  define MIMETREEPARSER_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > MIMETREEPARSER_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define MIMETREEPARSER_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#endif /* MIMETREEPARSER_EXPORT_H */
